# PY ENC

Nti Johanneberg gymnasiearbete 2023/2024

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install the required packages.

```bash
python -m pip install -r requirements.txt
```

## Run tests

```bash
python -m pytest
```
